/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the New BSD License (3-clause license).
 *
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the New BSD License (3-clause license)
 * for more details.
 *
 * You should have received a copy of the New BSD License (3-clause license)
 * along with this program/library; If not, see http://directory.fsf.org/wiki/License:BSD_3Clause/
 * for the New BSD License (3-clause license).
 */
package com.ebmwebsourcing.easycommons.lang;

import static org.junit.Assert.assertArrayEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import org.junit.Test;

/**
 * @author Adrien Ruffie - EBM WebSourcing
 */
public class ArrayHelperTest {

    @Test
    public void testMergeArrays0() throws Exception {
        Integer[] mergedArray = ArrayHelper.mergeArrays(new Integer[0]);
        assertArrayEquals(new Integer[0], mergedArray);
    }

    @Test
    public void testMergeArrays1() throws Exception {
        Integer[] mergedArray = ArrayHelper.mergeArrays(new Integer[0],
                new Integer[0], new Integer[0]);
        assertArrayEquals(new Integer[0], mergedArray);
    }

    @Test
    public void testMergeArrays2() throws Exception {
        Integer[] mergedArray = ArrayHelper.mergeArrays(
                new Integer[] { 1, 2, 3 }, new Integer[] { 4, 5 },
                new Integer[] { 6 });
        assertArrayEquals(new Integer[] { 1, 2, 3, 4, 5, 6 }, mergedArray);
    }

    @Test
    public void testArrayRemove0() throws Exception {
        Integer[] originalArray = new Integer[] { 1, 2, 3, 4, 5, 6 };
        Integer[] result = ArrayHelper.arrayRemove(originalArray);
        assertArrayEquals(originalArray, result);
    }

    @Test
    public void testArrayRemove1() throws Exception {
        Integer[] originalArray = new Integer[] { 1, 2, 3, 4, 5, 6 };
        Integer[] result = ArrayHelper.arrayRemove(originalArray, 7, 8, 9);
        assertArrayEquals(originalArray, result);
    }

    @Test
    public void testArrayRemove2() throws Exception {
        Integer[] originalArray = new Integer[] { 1, 2, 3, 4, 5, 6 };
        Integer[] result = ArrayHelper.arrayRemove(originalArray, 2, 3, 5);
        assertArrayEquals(new Integer[] { 1, 4, 6 }, result);
    }

    @Test
    public void testArrayContainsSameObject0() throws Exception {
        StringBuilder s1 = new StringBuilder("s1");
        StringBuilder s2 = new StringBuilder("s2");
        StringBuilder s3 = new StringBuilder("s3");
        StringBuilder[] array = new StringBuilder[] { s1, s2, s3 };
        for (StringBuilder s : new StringBuilder[] { s1, s2, s3 }) {
            assertTrue(ArrayHelper.arrayContainsSameObject(array, s));
        }
    }

    @Test
    public void testArrayContainsSameObject1() throws Exception {
        StringBuilder s1 = new StringBuilder("s1");
        StringBuilder s2 = new StringBuilder("s2");
        StringBuilder s3 = new StringBuilder("s3");
        StringBuilder[] array = new StringBuilder[] { s1, s2, s3 };
        for (StringBuilder s : new StringBuilder[] { new StringBuilder("s1"), new StringBuilder("s2"),
                new StringBuilder("s3") }) {
            assertFalse(ArrayHelper.arrayContainsSameObject(array, s));
        }
    }

}
